==> jmb.news-0.1.tar.gz: jmb.news-0.1/jmb/news/cms/views.py <==
# -*- coding: utf-8 -*-
from django.views.generic import ListView, DetailView
from jmb.news.models import News, Category

from django.core.paginator import Paginator, InvalidPage, EmptyPage
from django.shortcuts import get_object_or_404
from django.template import RequestContext
from django.shortcuts import render_to_response
from django.db.models import Q
from django.views.generic.list_detail import object_list
from django.views.generic.dates import YearArchiveView, MonthArchiveView, DayArchiveView

from jmb.news.models import News, Category
from jmb.news.forms import RicercaNewsForm



class NewsDetailView(DetailView):
    context_object_name = 'news_news_detail_by_slug'
    template_name = 'cms_apps/news_detail.html'
    model = News

#    def get_context_data(self, **kwargs):
#        context = super(NewsDetailView, self).get_context_data(**kwargs)
#        return context


#class NewsListView(ListView):
#
#    def __init__(self):
#        super(NewsListView, self).__init__()
#
#    def get_queryset(self):
#        pass


#class NewsYearArchiveView(YearArchiveView):
#    model = News
#    date_field = "pub_date_begin"
#
#


class NewsMonthArchiveView(MonthArchiveView):


    context_object_name = 'news_news_list_by_month'
    template_name = 'cms_apps/news_monthly_list.html'
    date_field = 'event_date'
    model = News

    def get_context_data(self, **kwargs):
        print 'yyy'
        context = super(NewsMonthArchiveView, self).get_context_data(**kwargs)
#        month = context['month']
#        news_qs = News.objects.filter('event_date__month',month.month).filter(status=1)
#        context['news'] = news_qs
        return context


#class NewsDayArchiveView(DayArchiveView):
#    model = News
#    pass

#class ModelListView(ListView):
#    context_object_name = 'app_model_list'
#    template_name = 'cms_apps/model_list.html'
#
#    def get_queryset(self):
#       if self.kwargs.has_key('slug'):
#           return Model.objects.filter(slug=self.kwargs['slug'])
#       else:
#           context = super(ModelListView, self).get_context_data(**self.kwargs)
#           return Model.objects.filter()
#
#class ModelDetailView(DetailView):
#    context_object_name = 'app_model_detail'
#    template_name = 'cms_apps/model_detail.html'
#    model = Model
#
#    def get_context_data(self, **kwargs):
#        context = super(ModelDetailView, self).get_context_data(**kwargs)
#        model = Model.objects.filter()

==> jmb.news-0.1.3.tar.gz: jmb.news-0.1.3/jmb/news/cms/views.py <==
# -*- coding: utf-8 -*-
from django.views.generic import ListView, DetailView
from jmb.news.models import News, Category

from django.core.paginator import Paginator, InvalidPage, EmptyPage
from django.shortcuts import get_object_or_404
from django.template import RequestContext
from django.shortcuts import render_to_response
from django.db.models import Q
from django.views.generic.list_detail import object_list
from django.views.generic.dates import YearArchiveView, MonthArchiveView, DayArchiveView

from jmb.news.models import News, Category
from jmb.news.forms import SearchNewsForm



class NewsDetailView(DetailView):
    context_object_name = 'news_news_detail_by_slug'
    template_name = 'news/cms_apps/news_detail.html'
    model = News

#    def get_context_data(self, **kwargs):
#        context = super(NewsDetailView, self).get_context_data(**kwargs)
#        return context


#class NewsListView(ListView):
#
#    def __init__(self):
#        super(NewsListView, self).__init__()
#
#    def get_queryset(self):
#        pass


#class NewsYearArchiveView(YearArchiveView):
#    model = News
#    date_field = "pub_date_begin"
#
#


class NewsMonthArchiveView(MonthArchiveView):


    context_object_name = 'news_news_list_by_month'
    template_name = 'news/cms_apps/news_monthly_list.html'
    date_field = 'event_date'
    model = News

    def get_context_data(self, **kwargs):
        context = super(NewsMonthArchiveView, self).get_context_data(**kwargs)
#        month = context['month']
#        news_qs = News.objects.filter('event_date__month',month.month).filter(status=1)
#        context['news'] = news_qs
        return context


#class NewsDayArchiveView(DayArchiveView):
#    model = News
#    pass

#class ModelListView(ListView):
#    context_object_name = 'app_model_list'
#    template_name = 'cms_apps/model_list.html'
#
#    def get_queryset(self):
#       if self.kwargs.has_key('slug'):
#           return Model.objects.filter(slug=self.kwargs['slug'])
#       else:
#           context = super(ModelListView, self).get_context_data(**self.kwargs)
#           return Model.objects.filter()
#
#class ModelDetailView(DetailView):
#    context_object_name = 'app_model_detail'
#    template_name = 'cms_apps/model_detail.html'
#    model = Model
#
#    def get_context_data(self, **kwargs):
#        context = super(ModelDetailView, self).get_context_data(**kwargs)
#        model = Model.objects.filter()
